@@ -1,3 +1,7 @@
 # read version from installed package
 from importlib.metadata import version
-__version__ = version("urbanity")
\ No newline at end of file
+__version__ = version("urbanity")
+
+from .urbanity import *
+from .utils import *
+from .geom import *
\ No newline at end of file
